==> stepfunctions-tasks-1.85.0-sources.jar: software/amazon/awscdk/services/stepfunctions/tasks/InvokeActivityProps.java <==
package software.amazon.awscdk.services.stepfunctions.tasks;

/**
 * Properties for FunctionTask.
 */
@javax.annotation.Generated(value = "jsii-pacmak/1.15.0 (build 585166b)", date = "2021-01-14T21:02:43.038Z")
@software.amazon.jsii.Jsii(module = software.amazon.awscdk.services.stepfunctions.tasks.$Module.class, fqn = "@aws-cdk/aws-stepfunctions-tasks.InvokeActivityProps")
@software.amazon.jsii.Jsii.Proxy(InvokeActivityProps.Jsii$Proxy.class)
@software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
public interface InvokeActivityProps extends software.amazon.jsii.JsiiSerializable {

    /**
     * Maximum time between heart beats.
     * <p>
     * If the time between heart beats takes longer than this, a 'Timeout' error is raised.
     * <p>
     * Default: No heart beat timeout
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    default @org.jetbrains.annotations.Nullable software.amazon.awscdk.core.Duration getHeartbeat() {
        return null;
    }

    /**
     * @return a {@link Builder} of {@link InvokeActivityProps}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    static Builder builder() {
        return new Builder();
    }
    /**
     * A builder for {@link InvokeActivityProps}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public static final class Builder implements software.amazon.jsii.Builder<InvokeActivityProps> {
        private software.amazon.awscdk.core.Duration heartbeat;

        /**
         * Sets the value of {@link InvokeActivityProps#getHeartbeat}
         * @param heartbeat Maximum time between heart beats.
         *                  If the time between heart beats takes longer than this, a 'Timeout' error is raised.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder heartbeat(software.amazon.awscdk.core.Duration heartbeat) {
            this.heartbeat = heartbeat;
            return this;
        }

        /**
         * Builds the configured instance.
         * @return a new instance of {@link InvokeActivityProps}
         * @throws NullPointerException if any required attribute was not provided
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        @Override
        public InvokeActivityProps build() {
            return new Jsii$Proxy(heartbeat);
        }
    }

    /**
     * An implementation for {@link InvokeActivityProps}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    @software.amazon.jsii.Internal
    final class Jsii$Proxy extends software.amazon.jsii.JsiiObject implements InvokeActivityProps {
        private final software.amazon.awscdk.core.Duration heartbeat;

        /**
         * Constructor that initializes the object based on values retrieved from the JsiiObject.
         * @param objRef Reference to the JSII managed object.
         */
        protected Jsii$Proxy(final software.amazon.jsii.JsiiObjectRef objRef) {
            super(objRef);
            this.heartbeat = software.amazon.jsii.Kernel.get(this, "heartbeat", software.amazon.jsii.NativeType.forClass(software.amazon.awscdk.core.Duration.class));
        }

        /**
         * Constructor that initializes the object based on literal property values passed by the {@link Builder}.
         */
        protected Jsii$Proxy(final software.amazon.awscdk.core.Duration heartbeat) {
            super(software.amazon.jsii.JsiiObject.InitializationMode.JSII);
            this.heartbeat = heartbeat;
        }

        @Override
        public final software.amazon.awscdk.core.Duration getHeartbeat() {
            return this.heartbeat;
        }

        @Override
        @software.amazon.jsii.Internal
        public com.fasterxml.jackson.databind.JsonNode $jsii$toJson() {
            final com.fasterxml.jackson.databind.ObjectMapper om = software.amazon.jsii.JsiiObjectMapper.INSTANCE;
            final com.fasterxml.jackson.databind.node.ObjectNode data = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();

            if (this.getHeartbeat() != null) {
                data.set("heartbeat", om.valueToTree(this.getHeartbeat()));
            }

            final com.fasterxml.jackson.databind.node.ObjectNode struct = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();
            struct.set("fqn", om.valueToTree("@aws-cdk/aws-stepfunctions-tasks.InvokeActivityProps"));
            struct.set("data", data);

            final com.fasterxml.jackson.databind.node.ObjectNode obj = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();
            obj.set("$jsii.struct", struct);

            return obj;
        }

        @Override
        public final boolean equals(final Object o) {
            if (this == o) return true;
            if (o == null || getClass() != o.getClass()) return false;

            InvokeActivityProps.Jsii$Proxy that = (InvokeActivityProps.Jsii$Proxy) o;

            return this.heartbeat != null ? this.heartbeat.equals(that.heartbeat) : that.heartbeat == null;
        }

        @Override
        public final int hashCode() {
            int result = this.heartbeat != null ? this.heartbeat.hashCode() : 0;
            return result;
        }
    }
}

==> stepfunctions-tasks-1.97.0-sources.jar: software/amazon/awscdk/services/stepfunctions/tasks/InvokeActivityProps.java <==
package software.amazon.awscdk.services.stepfunctions.tasks;

/**
 * (deprecated) Properties for FunctionTask.
 * <p>
 * @deprecated use `StepFunctionsInvokeActivity` and `StepFunctionsInvokeActivityProps`.
 */
@javax.annotation.Generated(value = "jsii-pacmak/1.27.0 (build 07d848a)", date = "2021-04-06T14:02:41.524Z")
@software.amazon.jsii.Jsii(module = software.amazon.awscdk.services.stepfunctions.tasks.$Module.class, fqn = "@aws-cdk/aws-stepfunctions-tasks.InvokeActivityProps")
@software.amazon.jsii.Jsii.Proxy(InvokeActivityProps.Jsii$Proxy.class)
@software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Deprecated)
@Deprecated
public interface InvokeActivityProps extends software.amazon.jsii.JsiiSerializable {

    /**
     * (deprecated) Maximum time between heart beats.
     * <p>
     * If the time between heart beats takes longer than this, a 'Timeout' error is raised.
     * <p>
     * Default: No heart beat timeout
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Deprecated)
    @Deprecated
    default @org.jetbrains.annotations.Nullable software.amazon.awscdk.core.Duration getHeartbeat() {
        return null;
    }

    /**
     * @return a {@link Builder} of {@link InvokeActivityProps}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Deprecated)
    @Deprecated
    static Builder builder() {
        return new Builder();
    }
    /**
     * A builder for {@link InvokeActivityProps}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Deprecated)
    @Deprecated
    public static final class Builder implements software.amazon.jsii.Builder<InvokeActivityProps> {
        private software.amazon.awscdk.core.Duration heartbeat;

        /**
         * Sets the value of {@link InvokeActivityProps#getHeartbeat}
         * @param heartbeat Maximum time between heart beats.
         *                  If the time between heart beats takes longer than this, a 'Timeout' error is raised.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Deprecated)
        @Deprecated
        public Builder heartbeat(software.amazon.awscdk.core.Duration heartbeat) {
            this.heartbeat = heartbeat;
            return this;
        }

        /**
         * Builds the configured instance.
         * @return a new instance of {@link InvokeActivityProps}
         * @throws NullPointerException if any required attribute was not provided
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Deprecated)
        @Deprecated
        @Override
        public InvokeActivityProps build() {
            return new Jsii$Proxy(heartbeat);
        }
    }

    /**
     * An implementation for {@link InvokeActivityProps}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Deprecated)
    @Deprecated
    @software.amazon.jsii.Internal
    final class Jsii$Proxy extends software.amazon.jsii.JsiiObject implements InvokeActivityProps {
        private final software.amazon.awscdk.core.Duration heartbeat;

        /**
         * Constructor that initializes the object based on values retrieved from the JsiiObject.
         * @param objRef Reference to the JSII managed object.
         */
        protected Jsii$Proxy(final software.amazon.jsii.JsiiObjectRef objRef) {
            super(objRef);
            this.heartbeat = software.amazon.jsii.Kernel.get(this, "heartbeat", software.amazon.jsii.NativeType.forClass(software.amazon.awscdk.core.Duration.class));
        }

        /**
         * Constructor that initializes the object based on literal property values passed by the {@link Builder}.
         */
        protected Jsii$Proxy(final software.amazon.awscdk.core.Duration heartbeat) {
            super(software.amazon.jsii.JsiiObject.InitializationMode.JSII);
            this.heartbeat = heartbeat;
        }

        @Override
        public final software.amazon.awscdk.core.Duration getHeartbeat() {
            return this.heartbeat;
        }

        @Override
        @software.amazon.jsii.Internal
        public com.fasterxml.jackson.databind.JsonNode $jsii$toJson() {
            final com.fasterxml.jackson.databind.ObjectMapper om = software.amazon.jsii.JsiiObjectMapper.INSTANCE;
            final com.fasterxml.jackson.databind.node.ObjectNode data = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();

            if (this.getHeartbeat() != null) {
                data.set("heartbeat", om.valueToTree(this.getHeartbeat()));
            }

            final com.fasterxml.jackson.databind.node.ObjectNode struct = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();
            struct.set("fqn", om.valueToTree("@aws-cdk/aws-stepfunctions-tasks.InvokeActivityProps"));
            struct.set("data", data);

            final com.fasterxml.jackson.databind.node.ObjectNode obj = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();
            obj.set("$jsii.struct", struct);

            return obj;
        }

        @Override
        public final boolean equals(final Object o) {
            if (this == o) return true;
            if (o == null || getClass() != o.getClass()) return false;

            InvokeActivityProps.Jsii$Proxy that = (InvokeActivityProps.Jsii$Proxy) o;

            return this.heartbeat != null ? this.heartbeat.equals(that.heartbeat) : that.heartbeat == null;
        }

        @Override
        public final int hashCode() {
            int result = this.heartbeat != null ? this.heartbeat.hashCode() : 0;
            return result;
        }
    }
}
